@@ -105,7 +105,7 @@ class HintLogicABC(object, metaclass=ABCMeta):
         :data:`True` only if the Python code snippet dynamically generated by
         calling the :attr:`code_format` method requires a pseudo-random integer
         by accessing the local variable named
-        :data:`beartype._check.checkmagic.VAR_NAME_RANDOM_INT`. If :data:`True`,
+        :data:`beartype._data.code.datacodename.VAR_NAME_RANDOM_INT`. If :data:`True`,
         the body of the current wrapper function will be prefixed by a Python
         statement assigning such an integer to that local variable.
     _get_cause_enumerator_item : _GetCauseEnumeratorItem
