@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2024 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -17,14 +17,14 @@ from beartype.typing import (
     Any,
     Optional,
 )
+from beartype._cave._cavefast import ModuleType
 from beartype._cave._cavemap import NoneTypeOr
 from beartype._data.cls.datacls import TYPE_BUILTIN_NAME_TO_TYPE
-from beartype._data.hint.datahinttyping import TypeException
+from beartype._data.typing.datatyping import TypeException
+from beartype._util.error.utilerrwarn import issue_warning
 from beartype._util.text.utiltextidentifier import die_unless_identifier
-from beartype._util.utilobject import SENTINEL
+from beartype._data.kind.datakindiota import SENTINEL
 from importlib import import_module as importlib_import_module
-from types import ModuleType
-from warnings import warn
 
 # ....................{ IMPORTERS                          }....................
 #FIXME: Preserved until requisite, which shouldn't be long.
@@ -96,12 +96,12 @@ def import_module_or_none(
     ----------
     module_name : str
         Fully-qualified name of the module to be imported.
-    exception_cls : Type[Exception]
-        Type of exception to be raised by this function. Defaults to
-        :class:`._BeartypeUtilModuleException`.
-    exception_prefix : str, optional
-        Human-readable label prefixing the representation of this object in the
-        exception message. Defaults to the empty string.
+    exception_cls : type[Exception], default: _BeartypeUtilModuleException
+        Type of exception to be raised in the event of a fatal error. Defaults
+        to :exc:`._BeartypeUtilModuleException`.
+    exception_prefix : str, default: "Module attribute "
+        Human-readable substring prefixing raised exception messages. Defaults
+        to a reasonably sensible prefix.
 
     Returns
     -------
@@ -119,8 +119,8 @@ def import_module_or_none(
     Warns
     -----
     BeartypeModuleUnimportableWarning
-        If a module with this name exists *but* that module is unimportable
-        due to raising module-scoped exceptions at importation time.
+        If a module with this name exists *but* that module is unimportable due
+        to raising module-scoped exceptions at importation time.
     '''
 
     # Avoid circular import dependencies.
@@ -153,12 +153,12 @@ def import_module_or_none(
     # If this module exists but raises unexpected exceptions from module scope,
     # first emit a non-fatal warning notifying the user and then return "None".
     except Exception as exception:
-        warn(
-            (
+        issue_warning(
+            cls=BeartypeModuleUnimportableWarning,
+            message=(
                 f'Ignoring module "{module_name}" importation exception:\n'
-                f'\t{exception.__class__.__name__}: {exception}'
+                f'    {exception.__class__.__name__}: {exception}'
             ),
-            BeartypeModuleUnimportableWarning,
         )
 
     # Inform the caller that this module is unimportable.
