@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
@@ -23,7 +23,7 @@ from beartype.vale._util._valeutiltyping import (
     BeartypeValidatorTester,
     BeartypeValidatorRepresenter,
 )
-from beartype._data.hint.datahinttyping import LexicalScope
+from beartype._data.typing.datatyping import LexicalScope
 from beartype._util.func.arg.utilfuncargtest import is_func_argless
 from beartype._util.text.utiltextrepr import represent_object
 
@@ -81,12 +81,10 @@ class BeartypeValidator(object):
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
     # CAUTION: Subclasses declaring uniquely subclass-specific instance
     # variables *MUST* additionally slot those variables. Subclasses violating
-    # this constraint will be usable but unslotted, which defeats our purposes.
+    # this constraint will be usable but unslotted, which defeats the purpose.
     #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
-    # Slot all instance variables defined on this object to minimize the time
-    # complexity of both reading and writing variables across frequently called
-    # cache dunder methods. Slotting has been shown to reduce read and write
-    # costs by approximately ~10%, which is non-trivial.
+    # Slot all instance variables defined on this object to reduce the costs of
+    # both reading and writing these variables by approximately ~10%.
     __slots__ = (
         '_get_repr',
         '_is_valid',
@@ -142,7 +140,7 @@ class BeartypeValidator(object):
             type hint for further details.
 
         Raises
-        ----------
+        ------
         beartype.roar.BeartypeValeSubscriptionException
             If either:
 
@@ -311,7 +309,7 @@ class BeartypeValidator(object):
         This function is memoized for efficiency.
 
         Warns
-        ----------
+        -----
         BeartypeValeLambdaWarning
             If this validator is implemented as a pure-Python lambda function
             whose definition is *not* parsable from the script or module
@@ -368,10 +366,11 @@ class BeartypeValidator(object):
             delimiting the human-readable representation of the tri-state
             boolean and validator representation in the returned substring).
         is_shortcircuited : bool, optional
-            ``True`` only if this validator has been **short-circuited** (i.e.,
-            *not* required to be tested against) by a previously tested sibling
-            validator, in which case this method will silently catch and reduce
-            exceptions raised by the :meth:`is_valid` method to ``False``.
+            :data:`True` only if this validator has been **short-circuited**
+            (i.e., *not* required to be tested against) by a previously tested
+            sibling validator, in which case this method will silently catch and
+            reduce exceptions raised by the :meth:`is_valid` method to
+            :data:`False`.
 
             Short-circuiting typically arises from binary validators (e.g.,
             :class:`beartype.vale._core._valecore.BeartypeValidatorConjunction`)
@@ -419,10 +418,10 @@ class BeartypeValidator(object):
                    IsArrayMatrix = Is[lambda arr: arr.shape[0] == arr.shape[1]]
                IndexError: tuple index out of range
 
-            Defaults to ``False``.
+            Defaults to :data:`False`.
 
         Returns
-        ----------
+        -------
         str
             Substring diagnosing this object against this validator.
         '''
@@ -440,7 +439,7 @@ class BeartypeValidator(object):
             # If doing so raises an exception, this short-circuited validator
             # was *NOT* intended to be called under short-circuiting. In this
             # case, silently ignore this exception. See the above discussion.
-            except:
+            except Exception:
                 pass
         # Else, this validator is *NOT* short-circuited. In this case, this
         # validator is *NOT* expected to raise exceptions. Nonetheless, if this
