@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-**Beartype functional validation classes** (i.e., :mod:`beartype`-specific
+Beartype **functional validation classes** (i.e., :mod:`beartype`-specific
 classes enabling callers to define PEP-compliant validators from arbitrary
 caller-defined callables *not* efficiently generating stack-free code).
 
@@ -19,58 +19,26 @@ from beartype.roar import (
     BeartypeValeLambdaWarning,
     BeartypeValeValidationException,
 )
+from beartype.typing import Protocol
 from beartype.vale._is._valeisabc import _BeartypeValidatorFactoryABC
 from beartype.vale._core._valecore import BeartypeValidator
 from beartype.vale._util._valeutilfunc import die_unless_validator_tester
 from beartype.vale._util._valeutiltyping import BeartypeValidatorTester
-from beartype._data.hint.datahinttyping import LexicalScope
+from beartype._data.typing.datatyping import LexicalScope
 from beartype._util.func.utilfuncscope import add_func_scope_attr
-from beartype._util.py.utilpyversion import IS_PYTHON_AT_LEAST_3_8
 from beartype._util.text.utiltextrepr import (
     represent_func,
     represent_object,
 )
 
-# ....................{ PRIVATE ~ protocols                }....................
-# If the active Python interpreter targets Python >= 3.8 and thus supports
-# PEP 544-compliant protocols...
-if IS_PYTHON_AT_LEAST_3_8:
-    # Defer version-specific imports.
-    from beartype.typing import Protocol
-
-    class _SupportsBool(Protocol):
-        '''
-        Fast caching protocol matching any object whose class defines the
-        :meth:`__bool__` dunder method.
-        '''
-
-        def __bool__(self) -> bool: ...
-
-
-    class _SupportsLen(Protocol):
-        '''
-        Fast caching protocol matching any object whose class defines the
-        :meth:`__len__` dunder method.
-        '''
-
-        def __len__(self) -> bool: ...
-
-
-    _BoolLike = (_SupportsBool, _SupportsLen)
-    '''
-    :func:`isinstance`-able tuple of fast caching protocols matching any
-    **bool-like** (i.e., object whose class defines at least one of the
-    :meth:`__bool__` and/or :meth:`__len__` dunder methods).
-    '''
-
 # ....................{ PRIVATE ~ subclasses               }....................
 class _IsFactory(_BeartypeValidatorFactoryABC):
     '''
     **Beartype callable validator factory** (i.e., class that, when subscripted
-    (indexed) by an arbitrary callable returning ``True`` when the object
+    (indexed) by an arbitrary callable returning :data:`True` when the object
     passed to that callable satisfies a caller-defined constraint, creates a
-    new :class:`BeartypeValidator` object encapsulating that callable suitable
-    for subscripting (indexing) :attr:`typing.Annotated` type hints, enforcing
+    new :class:`.BeartypeValidator` object encapsulating that callable suitable
+    for subscripting (indexing) :obj:`typing.Annotated` type hints, enforcing
     that constraint on :mod:`beartype`-decorated callable parameters and
     returns annotated by those hints).
 
@@ -83,7 +51,7 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
     data structures defined by third-party packages like NumPy arrays and
     Pandas DataFrames.
 
-    This class creates one new :class:`BeartypeValidator` object for each
+    This class creates one new :class:`.BeartypeValidator` object for each
     callable validator subscripting (indexing) this class. These objects:
 
     * Are **PEP-compliant** and thus guaranteed to *never* violate existing or
@@ -93,44 +61,44 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
     * **Less efficient** than :class:`BeartypeValidator` objects created by
       subscripting every other :mod:`beartype.vale` class. Specifically:
 
-      * Every :class:`BeartypeValidator` object created by subscripting this
+      * Every :class:`.BeartypeValidator` object created by subscripting this
         class necessarily calls a callable validator and thus incurs at least
         one additional call stack frame per :mod:`beartype`-decorated callable
         call.
-      * Every :class:`BeartypeValidator` object created by subscripting every
+      * Every :class:`.BeartypeValidator` object created by subscripting every
         other :mod:`beartype.vale` class directly calls *no* callable and thus
         incurs additional call stack frames only when the active Python
         interpreter internally calls dunder methods (e.g., ``__eq__()``) to
         satisfy their validation constraint.
 
     Usage
-    ----------
+    -----
     Any :mod:`beartype`-decorated callable parameter or return annotated by a
-    :attr:`typing.Annotated` type hint subscripted (indexed) by this class
+    :obj:`typing.Annotated` type hint subscripted (indexed) by this class
     subscripted (indexed) by a callable validator (e.g.,
     ``typing.Annotated[{cls}, beartype.vale.Is[lambda obj: {expr}]]`` for any
-    class ``{cls}``  and Python expression ``{expr}` evaluating to a boolean)
+    class ``{cls}``  and Python expression ``{expr}`` evaluating to a boolean)
     validates that parameter or return value to be an instance of that class
     satisfying that callable validator.
 
     Specifically, callers are expected to (in order):
 
     #. Annotate a callable parameter or return to be validated with a
-       :pep:`593`-compliant :attr:`typing.Annotated` type hint.
+       :pep:`593`-compliant :obj:`typing.Annotated` type hint.
     #. Subscript that hint with (in order):
 
        #. The type expected by that parameter or return.
        #. One or more subscriptions (indexations) of this class, each itself
           subscripted (indexed) by a **callable validator** (i.e., callable
-          accepting a single arbitrary object and returning either ``True`` if
-          that object satisfies an arbitrary constraint *or* ``False``
+          accepting a single arbitrary object and returning either :data:`True`
+          if that object satisfies an arbitrary constraint *or* :data:`False`
           otherwise). If that hint is subscripted by:
 
           * Only one subscription of this class, that parameter or return
             satisfies that hint when both:
 
             * That parameter or return is an instance of the expected type.
-            * That validator returns ``True`` when passed that parameter or
+            * That validator returns :data:`True` when passed that parameter or
               return.
 
           * Two or more subscriptions of this class, that parameter or return
@@ -138,7 +106,8 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
 
             * That parameter or return is an instance of the expected type.
             * *All* callable validators subscripting *all* subscriptions of
-              this class return ``True`` when passed that parameter or return.
+              this class return :data:`True` when passed that parameter or
+              return.
 
           Formally, the signature of each callable validator *must* resemble:
 
@@ -166,26 +135,27 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
 
        Annotated[str, Is[lambda text: bool(text)]]
 
-    :class:`BeartypeValidator` objects also support an expressive
+    :class:`.BeartypeValidator` objects also support an expressive
     domain-specific language (DSL) enabling callers to trivially synthesize new
     objects from existing objects with standard Pythonic math operators:
 
-    * **Negation** (i.e., ``not``). Negating an :class:`BeartypeValidator`
+    * **Negation** (i.e., ``not``). Negating an :class:`.BeartypeValidator`
       object with the ``~`` operator synthesizes a new
-      :class:`BeartypeValidator` object whose validator returns ``True`` only
-      when the validator of the original object returns ``False``. For example,
-      the following type hint only accepts strings containing *no* periods:
+      :class:`.BeartypeValidator` object whose validator returns :data:`True`
+      only when the validator of the original object returns :data:`False`. For
+      example, the following type hint only accepts strings containing *no*
+      periods:
 
       .. code-block:: python
 
          Annotated[str, ~Is[lambda text: '.' in text]]
 
     * **Conjunction** (i.e., ``and``). Conjunctively combining two or more
-      :class:`BeartypeValidator` objects with the ``&`` operator synthesizes a
-      new :class:`BeartypeValidator` object whose validator returns ``True``
-      only when all data validators of the original objects return ``True``.
-      For example, the following type hint only accepts non-empty strings
-      containing *no* periods:
+      :class:`.BeartypeValidator` objects with the ``&`` operator synthesizes a
+      new :class:`.BeartypeValidator` object whose validator returns
+      :data:`True` only when all data validators of the original objects return
+      :data:`True`. For example, the following type hint only accepts non-empty
+      strings containing *no* periods:
 
       .. code-block:: python
 
@@ -195,11 +165,11 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
          )]
 
     * **Disjunction** (i.e., ``or``). Disjunctively combining two or more
-      :class:`BeartypeValidator` objects with the ``|`` operator synthesizes a
-      new :class:`BeartypeValidator` object whose validator returns ``True``
-      only when at least one validator of the original objects returns
-      ``True``. For example, the following type hint accepts both empty strings
-      *and* non-empty strings containing at least one period:
+      :class:`.BeartypeValidator` objects with the ``|`` operator synthesizes a
+      new :class:`.BeartypeValidator` object whose validator returns
+      :data:`True` only when at least one validator of the original objects
+      returns :data:`True`. For example, the following type hint accepts both
+      empty strings *and* non-empty strings containing at least one period:
 
       .. code-block:: python
 
@@ -211,10 +181,10 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
     See also the **Examples** subsection below.
 
     Caveats
-    ----------
+    -------
     **This class is currently only supported by the** :func:`beartype.beartype`
     **decorator.** All other static and runtime type checkers silently ignore
-    subscriptions of this class subscripting :attr:`typing.Annotated` type
+    subscriptions of this class subscripting :obj:`typing.Annotated` type
     hints.
 
     **This class incurs a minor time performance penalty at call time.**
@@ -228,11 +198,11 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
 
     **This class prohibits instantiation.** This class is *only* intended to be
     subscripted. Attempting to instantiate this class into an object will raise
-    an :exc:`BeartypeValeSubscriptionException` exception.
+    an :exc:`.BeartypeValeSubscriptionException` exception.
 
     Examples
-    ----------
-    .. code-block:: python
+    --------
+    .. code-block:: pycon
 
        # Import the requisite machinery.
        >>> from beartype import beartype
@@ -292,9 +262,9 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
         '''
         Create and return a new beartype validator from the passed **validator
         callable** (i.e., caller-defined callable accepting a single arbitrary
-        object and returning either ``True`` if that object satisfies an
-        arbitrary constraint *or* ``False`` otherwise), suitable for
-        subscripting :pep:`593`-compliant :attr:`typing.Annotated` type hints.
+        object and returning either :data:`True` if that object satisfies an
+        arbitrary constraint *or* :data:`Falsee` otherwise), suitable for
+        subscripting :pep:`593`-compliant :obj:`typing.Annotated` type hints.
 
         This method is intentionally *not* memoized, as this method is usually
         subscripted only by subscription-specific lambda functions uniquely
@@ -306,12 +276,12 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
             Validator callable to validate parameters and returns against.
 
         Returns
-        ----------
+        -------
         BeartypeValidator
             New object encapsulating this validator callable.
 
         Raises
-        ----------
+        ------
         BeartypeValeSubscriptionException
             If either:
 
@@ -323,8 +293,8 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
               * Is a pure-Python callable accepting two or more arguments.
 
         See Also
-        ----------
-        :class:`_IsAttrFactory`
+        --------
+        :class:`._IsAttrFactory`
             Usage instructions.
         '''
 
@@ -343,7 +313,7 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
         # expense of accurately retrieving the source code for this validator
         # (especially when this validator is itself a lambda function).
         get_repr = lambda: (
-            f'{self._basename}['
+            f'beartype.vale.{self._basename}['
             f'{represent_func(func=is_valid, warning_cls=BeartypeValeLambdaWarning)}'
             f']'
         )
@@ -352,7 +322,7 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
         #FIXME: Unit test edge cases extensively, please.
         def _is_valid_bool(obj: object) -> bool:
             '''
-            ``True`` only if the passed object satisfies the caller-defined
+            :data:`True` only if the passed object satisfies the caller-defined
             validation callable subscripting this :attr:`beartype.vale.Is`
             validator factory.
 
@@ -374,7 +344,7 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
             NumPy, which commonly return non-boolean objects that are implicitly
             convertible into boolean objects: e.g.,
 
-            .. code-block::
+            .. code-block:: pycon
 
                >>> import numpy as np
                >>> matrix = np.array([[2, 1], [1, 2]])
@@ -387,7 +357,7 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
                True
 
             Caveats
-            ----------
+            -------
             **This closure is comparatively slower than the passed callable.**
             This closure should *never* be called directly from code snippets
             embedded in wrapper functions dynamically generated by the
@@ -399,8 +369,8 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
             This implies that wrapper functions dynamically generated by the
             :func:`beartype.beartype` decorator *could* implicitly coerce
             non-boolean objects returned by the passed callable into the
-            ``True`` singleton. Although non-ideal, debugging such concerns is
-            squarely the user's concern; attempting to safeguard users from
+            ;data;`True` singleton. Although non-ideal, debugging such concerns
+            is squarely the user's concern; attempting to safeguard users from
             semantic issues like this would destroy runtime performance for *no*
             tangible gain in the general case. The best :mod:`beartype` can (and
             should) do is defer validation until a type-checking violation.
@@ -411,24 +381,21 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
                 Object to be validated by that validation callable.
 
             Returns
-            ----------
+            -------
             bool
-                ``True`` only if that object satisfies that validation callable.
+                :data:`True` only if that object satisfies that validation
+                callable.
 
             Raises
-            ----------
+            ------
             BeartypeValeValidationException
                 If that validation callable returns a **non-bool-like**, where
-                "non-bool-like" is any object that:
+                "non-bool-like" is any object that both:
 
                 * Is *not* a **boolean** (i.e., :class:`bool` instance).
                 * Is *not* **implicitly convertible** into a boolean (i.e., is
                   an object whose class defines neither the :meth:`__bool__` nor
                   :meth:`__len__` dunder methods).
-
-    * Subscript the :attr:`beartype.vale.Is` factory by a **non-bool-like
-      validator** (i.e., tester function returning an object that is neither a
-      :class:`bool` *nor* implicitly convertible into a :class:`bool`).
             '''
 
             # Object returned by validating this object against that callable.
@@ -505,25 +472,10 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
             # * Else, that constructor returns "True".
             #
             # To handle the first two cases, we instead:
-            #
-            # * Under Python >= 3.8, define both our own "SupportsBool" *AND*
-            #   "SupportsLen" protocols.
-            # * Under Python 3.7, fallback to slower getattr()-based tests.
-            is_obj_valid_boollike: bool = None  # type: ignore[assignment]
-
-            # If the active Python interpreter targets Python >= 3.8 and thus
-            # supports the PEP 544-compliant protocols defined above, decide
-            # whether that object is bool-like by deferring to those protocols.
-            if IS_PYTHON_AT_LEAST_3_8:
-                is_obj_valid_boollike = isinstance(is_obj_valid, _BoolLike)  # pyright: ignore
-            # Else, the active Python interpreter targets Python 3.7 and thus
-            # fails to support the PEP 544-compliant protocols defined above.
-            # Instead, decide whether that object is bool-like manually.
-            else:
-                is_obj_valid_boollike = (
-                    hasattr(is_obj_valid, '__bool__') or
-                    hasattr(is_obj_valid, '__len__')
-                )
+            # * Define both our own "SupportsBool" and "SupportsLen" protocols.
+            # * Decide whether that object is bool-like by deferring to those
+            #   protocols.
+            is_obj_valid_boollike = isinstance(is_obj_valid, _BoolLike)  # pyright: ignore
 
             # If that object is *NOT* bool-like, raise an exception.
             if not is_obj_valid_boollike:
@@ -591,3 +543,29 @@ class _IsFactory(_BeartypeValidatorFactoryABC):
             is_valid_code_locals=is_valid_code_locals,
             get_repr=get_repr,
         )
+
+# ....................{ PRIVATE ~ protocols                }....................
+class _SupportsBool(Protocol):
+    '''
+    Fast caching protocol matching any object whose class defines the
+    :meth:`__bool__` dunder method.
+    '''
+
+    def __bool__(self) -> bool: ...
+
+
+class _SupportsLen(Protocol):
+    '''
+    Fast caching protocol matching any object whose class defines the
+    :meth:`__len__` dunder method.
+    '''
+
+    def __len__(self) -> bool: ...
+
+
+_BoolLike = (_SupportsBool, _SupportsLen)
+'''
+:func:`isinstance`-able tuple of fast caching protocols matching any
+**bool-like** (i.e., object whose class defines at least one of the
+:meth:`__bool__` and/or :meth:`__len__` dunder methods).
+'''
