@@ -1,11 +1,11 @@
 #!/usr/bin/env python3
 # --------------------( LICENSE                            )--------------------
-# Copyright (c) 2014-2023 Beartype authors.
+# Copyright (c) 2014-2025 Beartype authors.
 # See "LICENSE" for further details.
 
 '''
-**Beartype Decidedly Object-Oriented Runtime-checking (DOOR) API object-oriented
-unit tests.**
+Beartype **Decidedly Object-Oriented Runtime-checking (DOOR) API
+object-oriented** unit tests.
 
 This submodule unit tests the subset of the public API of the public
 :mod:`beartype.door` subpackage that is object-oriented.
@@ -16,6 +16,7 @@ This submodule unit tests the subset of the public API of the public
 # WARNING: To raise human-readable test errors, avoid importing from
 # package-specific submodules at module scope.
 #!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
+from beartype_test._util.mark.pytmark import ignore_warnings
 
 # ....................{ TESTS ~ dunder ~ creation          }....................
 def test_door_typehint_new() -> None:
@@ -69,12 +70,20 @@ def test_door_typehint_new() -> None:
         typehint = TypeHint(b'Is there, that from the boundaries of the sky')
 
 
-def test_door_typehint_mapping() -> None:
+def test_door_typehint_mapping(iter_hints_piths_meta) -> None:
     '''
     Test that the :meth:`beartype.door.TypeHint.__new__` factory method
     successfully creates and returns an instance of a concrete subclass of the
     abstract :class:`beartype.door.TypeHint` superclass conditionally handling
     the kind of low-level type hint passed to that factory method.
+
+    Parameters
+    ----------
+    iter_hints_piths_meta : Callable[[], Iterable[beartype_test.a00_unit.data.hint.util.data_hintmetautil.HintPithMetadata]]
+        Factory function creating and returning a generator iteratively yielding
+        ``HintPithMetadata`` instances, each describing a sample type hint
+        exercising an edge case in the :mod:`beartype` codebase paired with a
+        related object either satisfying or violating that hint.
     '''
 
     # ....................{ IMPORTS                        }....................
@@ -82,8 +91,6 @@ def test_door_typehint_mapping() -> None:
     from beartype.door import TypeHint
     from beartype_test.a00_unit.data.hint.util.data_hintmetacls import (
         HintPepMetadata)
-    from beartype_test.a00_unit.data.hint.util.data_hintmetautil import (
-        iter_hints_piths_meta)
 
     # ....................{ ASSERTS                        }....................
     # For each predefined type hint and associated metadata...
@@ -116,11 +123,16 @@ def test_door_typehint_mapping() -> None:
         assert isinstance(wrapper, hint_meta.typehint_cls)
 
         # ....................{ PROPERTIES                 }....................
-        # Assert that the type hint wrapped by this instance is the same hint.
+        # Assert that the type hint wrapped by this instance is equal to the
+        # same hint. Note that, due to memoization, the type hint wrapped by
+        # this instance is only typically but *NOT* necessarily identical to the
+        # same hint. In theory, an "is"-based identity test would be preferable
+        # to an "=="-based equality test; in practice, the former would induce
+        # false positives in common edge cases.
         wrapper_hint = wrapper.hint
         # print(f'wrapper_hint: {repr(wrapper_hint), id(wrapper_hint), type(wrapper_hint)}')
         # print(f'hint: {repr(hint),  id(hint), type(hint)}')
-        assert wrapper_hint is hint
+        assert wrapper_hint == hint
 
 # ....................{ TESTS ~ dunders                    }....................
 #FIXME: Insufficient. Generalize to test *ALL* possible kinds of type hints.
@@ -332,22 +344,28 @@ def test_door_typehint_len():
 #FIXME: Implement this up, please. We'll want to pay particular attention to
 #edge cases in those "TypeHint" implementations overriding the _make_args()
 #superclass method. In all likelihood, this will warrant yet another fixture.
-# def test_door_typehint_args() -> None:
+# def test_door_typehint_args(hints_pep_meta, hints_ignorable) -> None:
 #     '''
 #     Test the read-only :meth:`beartype.door.TypeHint.args` property.
+#
+#     Parameters
+#     ----------
+#     hints_pep_meta : tuple[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+#         Tuple of type hint metadata describing sample type hints exercising edge
+#         cases in the :mod:`beartype` codebase.
+#     hints_ignorable : frozenset
+#         Frozen set of ignorable PEP-agnostic type hints.
 #     '''
 #
 #     # Defer test-specific imports.
 #     from beartype.door import TypeHint
 #     from beartype.roar import BeartypeDoorException, BeartypeDoorNonpepException
-#     from beartype_test.a00_unit.data.hint.data_hint import HINTS_IGNORABLE
-#     from beartype_test.a00_unit.data.hint.pep.data_pep import HINTS_PEP_META
 #     from contextlib import suppress
 #
 #     # Assert this method:
 #     # * Accepts unignorable PEP-compliant type hints.
 #     # * Rejects ignorable PEP-compliant type hints.
-#     for hint_pep_meta in HINTS_PEP_META:
+#     for hint_pep_meta in hints_pep_meta:
 #         #FIXME: Remove this suppression *AFTER* improving "TypeHint" to support
 #         #all currently unsupported type hints. Most of these will be
 #         #"BeartypeDoorNonpepException", but there are some covariant type hints
@@ -358,9 +376,20 @@ def test_door_typehint_len():
 #                 hint_pep_meta.is_ignorable)
 
 
-def test_door_typehint_is_ignorable() -> None:
+# Prevent pytest from capturing and displaying all expected non-fatal
+# beartype-specific warnings emitted by this test. Urgh!
+@ignore_warnings(DeprecationWarning)
+def test_door_typehint_is_ignorable(hints_pep_meta, hints_ignorable) -> None:
     '''
     Test the :meth:`beartype.door.TypeHint.is_ignorable` property.
+
+    Parameters
+    ----------
+    hints_pep_meta : tuple[beartype_test.a00_unit.data.hint.util.data_hintmetacls.HintPepMetadata]
+        Tuple of type hint metadata describing sample type hints exercising edge
+        cases in the :mod:`beartype` codebase.
+    hints_ignorable : frozenset
+        Frozen set of ignorable PEP-agnostic type hints.
     '''
 
     # ....................{ IMPORTS                        }....................
@@ -368,16 +397,15 @@ def test_door_typehint_is_ignorable() -> None:
     from beartype.door import TypeHint
     from beartype.roar import BeartypeDoorException, BeartypeDoorNonpepException
     from beartype.typing import TypeVar
-    from beartype._util.hint.utilhinttest import is_hint_ignorable
-    from beartype._util.hint.pep.proposal.pep484.utilpep484typevar import (
-        get_hint_pep484_typevar_bound_or_none)
-    from beartype_test.a00_unit.data.hint.data_hint import HINTS_IGNORABLE
-    from beartype_test.a00_unit.data.hint.pep.data_pep import HINTS_PEP_META
+    from beartype._check.convert.convmain import sanify_hint_any
+    from beartype._check.metadata.hint.hintsane import HINT_SANE_IGNORABLE
+    from beartype._util.hint.pep.proposal.pep484.pep484typevar import (
+        get_hint_pep484_typevar_bounded_constraints_or_none)
     from contextlib import suppress
 
     # ....................{ PASS                           }....................
     # Assert this property accepts ignorable type hints.
-    for hint_ignorable in HINTS_IGNORABLE:
+    for hint_ignorable in hints_ignorable:
         #FIXME: Remove this suppression *AFTER* improving "TypeHint" to support
         #all currently unsupported type hints.
         with suppress(BeartypeDoorNonpepException):
@@ -386,7 +414,7 @@ def test_door_typehint_is_ignorable() -> None:
     # Assert this property:
     # * Accepts unignorable PEP-compliant type hints.
     # * Rejects ignorable PEP-compliant type hints.
-    for hint_pep_meta in HINTS_PEP_META:
+    for hint_pep_meta in hints_pep_meta:
         # Hint to be tested.
         hint = hint_pep_meta.hint
 
@@ -408,7 +436,7 @@ def test_door_typehint_is_ignorable() -> None:
         if isinstance(hint, TypeVar):
             # Type hint synthesized from all bounded constraints parametrizing
             # this type variable if any *OR* "None" otherwise.
-            hint_typevar_bound = get_hint_pep484_typevar_bound_or_none(hint)
+            hint_typevar_bound = get_hint_pep484_typevar_bounded_constraints_or_none(hint)
 
             # This type hint is ignorable only if either...
             hint_is_ignorable = (
@@ -416,7 +444,7 @@ def test_door_typehint_is_ignorable() -> None:
                 hint_typevar_bound is None or
                 # This type hint is constrained by one or more ignorable
                 # constraints.
-                is_hint_ignorable(hint_typevar_bound)
+                sanify_hint_any(hint=hint_typevar_bound) is HINT_SANE_IGNORABLE
             )
         # Else, this hint is *NOT* a type variable.
 
@@ -434,7 +462,7 @@ def test_door_typehint_is_ignorable() -> None:
 def test_door_typehint_is_subhint_fail() -> None:
     '''
     Test unsuccessful usage of the
-    :meth:`beartype.door.TypeHint.is_subhint` tester.
+    :meth:`beartype.door.TypeHint.is_subhint` tester method.
     '''
 
     # Defer test-specific imports.
@@ -444,13 +472,23 @@ def test_door_typehint_is_subhint_fail() -> None:
     from pytest import raises
 
     hint = TypeHint(Callable[[], list])
+
     with raises(BeartypeDoorException, match='not type hint wrapper'):
         hint.is_subhint(int)
 
 
-def test_door_types_that_are_just_origins():
+def test_door_typehint_is_args_ignorable():
+    '''
+    Test the private :attr:`beartype.door.TypeHint._is_args_ignorable` boolean
+    instance variable.
+    '''
+
     from beartype.door import TypeHint
-    from beartype.typing import Any, Callable, Tuple
+    from beartype.typing import (
+        Any,
+        Callable,
+        Tuple,
+    )
 
     assert TypeHint(Callable)._is_args_ignorable
     assert TypeHint(Callable[..., Any])._is_args_ignorable
